@@ -20,25 +20,16 @@ struct PathTracer : public AddStructShared<Renderer, ispc::PathTracer>
   virtual void commit() override;
   virtual void *beginFrame(FrameBuffer *, World *) override;
 
-  virtual void renderTasks(FrameBuffer *fb,
+  virtual devicert::AsyncEvent renderTasks(FrameBuffer *fb,
       Camera *camera,
       World *world,
       void *perFrameData,
-      const utility::ArrayView<uint32_t> &taskIDs
-#ifdef OSPRAY_TARGET_SYCL
-      ,
-      sycl::queue &syclQueue
-#endif
-  ) const override;
+      const utility::ArrayView<uint32_t> &taskIDs) const override;
 
  private:
-  void generateGeometryLights(const World &, std::vector<ispc::Light *> &);
-  bool importanceSampleGeometryLights{
-      true}; // if geometry lights are importance
-             // sampled using NEE (requires scanning
-             // the scene for geometric lights)
-  bool scannedGeometryLights{
-      false}; // if the scene was scanned for geometric lights
+  bool scanForGeometryLights{true}; // if geometry lights are importance
+                                    // sampled using NEE (requires scanning
+                                    // the scene for geometric lights)
 };
 
 } // namespace ospray
