@@ -6,6 +6,9 @@
 // ospray
 #include "ospray/ospray.h"
 
+static_assert(
+    sizeof(bool) == 1, "OSPRay assumes the size of 'bool' to be 1 byte.");
+
 namespace ospray {
 
 // Infer (compile time) OSP_DATA_TYPE from input type /////////////////////////
@@ -60,25 +63,29 @@ OSPTYPEFOR_SPECIALIZATION(OSPVolume, OSP_VOLUME);
 OSPTYPEFOR_SPECIALIZATION(OSPVolumetricModel, OSP_VOLUMETRIC_MODEL);
 OSPTYPEFOR_SPECIALIZATION(OSPWorld, OSP_WORLD);
 
-OSPTYPEFOR_SPECIALIZATION(OSPLogLevel, OSP_INT);
-OSPTYPEFOR_SPECIALIZATION(OSPDeviceProperty, OSP_INT);
-OSPTYPEFOR_SPECIALIZATION(OSPDataType, OSP_INT);
-OSPTYPEFOR_SPECIALIZATION(OSPTextureFormat, OSP_INT);
-OSPTYPEFOR_SPECIALIZATION(OSPTextureFilter, OSP_INT);
-OSPTYPEFOR_SPECIALIZATION(OSPError, OSP_INT);
-OSPTYPEFOR_SPECIALIZATION(OSPFrameBufferFormat, OSP_INT);
-OSPTYPEFOR_SPECIALIZATION(OSPFrameBufferChannel, OSP_INT);
-OSPTYPEFOR_SPECIALIZATION(OSPSyncEvent, OSP_INT);
+OSPTYPEFOR_SPECIALIZATION(OSPLogLevel, OSP_UINT);
+OSPTYPEFOR_SPECIALIZATION(OSPDeviceProperty, OSP_UINT);
+OSPTYPEFOR_SPECIALIZATION(OSPDataType, OSP_UINT);
+OSPTYPEFOR_SPECIALIZATION(OSPTextureFormat, OSP_UINT);
+OSPTYPEFOR_SPECIALIZATION(OSPTextureFilter, OSP_UINT);
+OSPTYPEFOR_SPECIALIZATION(OSPTextureWrapMode, OSP_UINT);
+OSPTYPEFOR_SPECIALIZATION(OSPError, OSP_UINT);
+OSPTYPEFOR_SPECIALIZATION(OSPFrameBufferFormat, OSP_UINT);
+OSPTYPEFOR_SPECIALIZATION(OSPFrameBufferChannel, OSP_UINT);
+OSPTYPEFOR_SPECIALIZATION(OSPSyncEvent, OSP_UINT);
 OSPTYPEFOR_SPECIALIZATION(OSPUnstructuredCellType, OSP_UCHAR);
-OSPTYPEFOR_SPECIALIZATION(OSPStereoMode, OSP_UCHAR);
-OSPTYPEFOR_SPECIALIZATION(OSPShutterType, OSP_UCHAR);
-OSPTYPEFOR_SPECIALIZATION(OSPCurveType, OSP_UCHAR);
-OSPTYPEFOR_SPECIALIZATION(OSPCurveBasis, OSP_UCHAR);
-OSPTYPEFOR_SPECIALIZATION(OSPAMRMethod, OSP_UCHAR);
-OSPTYPEFOR_SPECIALIZATION(OSPSubdivisionMode, OSP_UCHAR);
-OSPTYPEFOR_SPECIALIZATION(OSPPixelFilterTypes, OSP_UCHAR);
-OSPTYPEFOR_SPECIALIZATION(OSPIntensityQuantity, OSP_UCHAR);
+OSPTYPEFOR_SPECIALIZATION(OSPStereoMode, OSP_UINT);
+OSPTYPEFOR_SPECIALIZATION(OSPShutterType, OSP_UINT);
+OSPTYPEFOR_SPECIALIZATION(OSPCurveType, OSP_UINT);
+OSPTYPEFOR_SPECIALIZATION(OSPCurveBasis, OSP_UINT);
+OSPTYPEFOR_SPECIALIZATION(OSPSubdivisionMode, OSP_UINT);
+OSPTYPEFOR_SPECIALIZATION(OSPAMRMethod, OSP_UINT);
+OSPTYPEFOR_SPECIALIZATION(OSPVolumeFilter, OSP_UINT);
 OSPTYPEFOR_SPECIALIZATION(OSPVolumeFormat, OSP_UINT);
+OSPTYPEFOR_SPECIALIZATION(OSPPixelFilterType, OSP_UINT);
+OSPTYPEFOR_SPECIALIZATION(OSPIntensityQuantity, OSP_UINT);
+OSPTYPEFOR_SPECIALIZATION(OSPSphereType, OSP_UINT);
+OSPTYPEFOR_SPECIALIZATION(OSPDenoiserQuality, OSP_UINT);
 
 #define OSPTYPEFOR_DEFINITION(type)                                            \
   constexpr OSPDataType OSPTypeFor<type>::value
